OtpFieldDecorator class abstract
Abstract interface for OTP field decoration Defines a method to obtain the input decoration for each OTP input box. This enables multiple different styles (boxed, circular, underline, custom).
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDecoration(
{bool hasError}) → InputDecoration -
Returns the InputDecoration for the OTP field at the given
index. ProvidesisFilledto indicate if this field currently has input. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited